@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Dict, List, Optional, Set, Type, Union, cast
+from typing import TYPE_CHECKING, Dict, List, Literal, Optional, Set, Type, Union, cast
 
 from pydantic import AnyUrl, BaseModel
 from pydantic_openapi_schema import construct_open_api_with_schema_class
@@ -15,7 +15,6 @@ from pydantic_openapi_schema.v3_1_0 import (
     Server,
     Tag,
 )
-from typing_extensions import Literal
 
 from starlite.openapi.controller import OpenAPIController
 from starlite.openapi.path_item import create_path_item
@@ -28,9 +27,8 @@ if TYPE_CHECKING:
 class OpenAPIConfig(BaseModel):
     """Configuration for OpenAPI.
 
-    To enable OpenAPI schema generation and serving, pass an instance of
-    this class to the [Starlite][starlite.app.Starlite] constructor
-    using the 'openapi_config' kwargs.
+    To enable OpenAPI schema generation and serving, pass an instance of this class to the
+    [Starlite][starlite.app.Starlite] constructor using the 'openapi_config' kwargs.
     """
 
     create_examples: bool = False
@@ -113,10 +111,7 @@ class OpenAPIConfig(BaseModel):
     """
 
     def to_openapi_schema(self) -> "OpenAPI":
-        """Generates an.
-
-        [OpenAPI][pydantic_openapi_schema.v3_1_0.open_api.OpenAPI] from the
-        values stored on 'self'.
+        """Return an `OpenAPI` instance from the values stored in `self`.
 
         Returns:
             An instance of [OpenAPI][pydantic_openapi_schema.v3_1_0.open_api.OpenAPI].
@@ -152,10 +147,7 @@ class OpenAPIConfig(BaseModel):
         )
 
     def create_openapi_schema_model(self, app: "Starlite") -> "OpenAPI":
-        """Creates instance of.
-
-        [OpenAPI][pydantic_openapi_schema.v3_1_0.open_api.OpenAPI] instance for
-        the given [Starlite][starlite.app.Starlite] application.
+        """Create and `OpenAPI` instance for the given application.
 
         Args:
             app (Starlite): [Starlite][starlite.app.Starlite] instance.
