@@ -10,7 +10,6 @@ from starlite.datastructures.multi_dicts import (
     FormMultiDict,
     ImmutableMultiDict,
     MultiDict,
-    QueryMultiDict,
 )
 from starlite.datastructures.provide import Provide
 from starlite.datastructures.response_containers import (
@@ -40,7 +39,6 @@ __all__ = (
     "MultiDict",
     "MutableScopeHeaders",
     "Provide",
-    "QueryMultiDict",
     "Redirect",
     "ResponseContainer",
     "ResponseHeader",
