@@ -31,7 +31,7 @@ class SessionModelMixin:
     """Mixin for session storage."""
 
     session_id: Mapped[str] = sa.Column(sa.String, nullable=False, unique=True, index=True)  # pyright: ignore
-    data: Mapped[bytes] = sa.Column(sa.BLOB, nullable=False)  # pyright: ignore
+    data: Mapped[bytes] = sa.Column(sa.LargeBinary, nullable=False)  # pyright: ignore
     expires: Mapped[datetime] = sa.Column(sa.DateTime, nullable=False)  # pyright: ignore
 
     @hybrid_property
@@ -199,6 +199,7 @@ class AsyncSQLAlchemyBackend(BaseSQLAlchemyBackend[AsyncSASession]):
         """
         async with self._create_sa_session() as sa_session:
             await sa_session.execute(sa.delete(self._model).where(self._model.expired))
+            await sa_session.commit()
 
 
 class SQLAlchemyBackend(BaseSQLAlchemyBackend[SASession]):
@@ -290,6 +291,7 @@ class SQLAlchemyBackend(BaseSQLAlchemyBackend[SASession]):
     def _delete_expired_sync(self) -> None:
         sa_session = self._create_sa_session()
         sa_session.execute(sa.delete(self._model).where(self._model.expired))
+        sa_session.commit()
 
     async def delete_expired(self) -> None:
         """Delete all expired session from the database.
@@ -309,7 +311,7 @@ class SQLAlchemyBackendConfig(ServerSideSessionConfig):
     @validator("plugin", always=True)
     def validate_plugin_config(cls, value: SQLAlchemyPlugin) -> SQLAlchemyPlugin:  # pylint: disable=no-self-argument)
         """Check if the SQLAlchemyPlugin is configured."""
-        if not (value._config and value._config.session_maker):  # pylint: disable=protected-access
+        if not (value._config and value._config.session_maker):
             raise ValueError("Plugin needs to be configured")
         return value
 
@@ -318,6 +320,6 @@ class SQLAlchemyBackendConfig(ServerSideSessionConfig):
         """Return either `SQLAlchemyBackend` or `AsyncSQLAlchemyBackend`, depending on the engine type configured in the
         `SQLAlchemyPlugin`
         """
-        if cast("SQLAlchemyPluginConfig", self.plugin._config).use_async_engine:  # pylint: disable=protected-access
+        if cast("SQLAlchemyPluginConfig", self.plugin._config).use_async_engine:
             return AsyncSQLAlchemyBackend
         return SQLAlchemyBackend
