@@ -1,4 +1,6 @@
+from copy import copy
 from http import HTTPStatus
+from operator import attrgetter
 from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, Tuple, Type
 
 from pydantic_openapi_schema.v3_1_0 import Response
@@ -40,7 +42,8 @@ def create_cookie_schema(cookie: "Cookie") -> Schema:
     Returns:
         Schema
     """
-    cookie_copy = cookie.copy(update={"value": "<string>"})
+    cookie_copy = copy(cookie)
+    cookie_copy.value = "<string>"
     value = cookie_copy.to_header(header="")
     return Schema(description=cookie.description or "", example=value)
 
@@ -131,7 +134,9 @@ def create_success_response(
     cookies = route_handler.resolve_response_cookies()
     if cookies:
         response.headers["Set-Cookie"] = Header(
-            param_schema=Schema(allOf=[create_cookie_schema(cookie=cookie) for cookie in cookies])
+            param_schema=Schema(
+                allOf=[create_cookie_schema(cookie=cookie) for cookie in sorted(cookies, key=attrgetter("key"))]
+            )
         )
     return response
 
