@@ -1,24 +1,15 @@
-from typing import TYPE_CHECKING, Any, Dict, Optional, cast
+from typing import TYPE_CHECKING, Any, Dict, Optional
 
-from starlite.controller import Controller
 from starlite.enums import ScopeType
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.routes.base import BaseRoute
 from starlite.signature import get_signature_model
-from starlite.utils import get_name
-from starlite.utils.dependency import resolve_dependencies_concurrently
 
 if TYPE_CHECKING:
     from starlite.connection import WebSocket
     from starlite.handlers.websocket import WebsocketRouteHandler
     from starlite.kwargs import KwargsModel
-    from starlite.types import (
-        AnyCallable,
-        AsyncAnyCallable,
-        Receive,
-        Send,
-        WebSocketScope,
-    )
+    from starlite.types import Receive, Send, WebSocketScope
 
 
 class WebSocketRoute(BaseRoute):
@@ -43,10 +34,11 @@ class WebSocketRoute(BaseRoute):
         """
         self.route_handler = route_handler
         self.handler_parameter_model: Optional["KwargsModel"] = None
+
         super().__init__(
             path=path,
             scope_type=ScopeType.WEBSOCKET,
-            handler_names=[get_name(cast("AnyCallable", route_handler.fn))],
+            handler_names=[route_handler.handler_name],
         )
 
     async def handle(self, scope: "WebSocketScope", receive: "Receive", send: "Send") -> None:  # type: ignore[override]
@@ -65,12 +57,7 @@ class WebSocketRoute(BaseRoute):
             await self.route_handler.authorize_connection(connection=websocket)
 
         kwargs = await self._resolve_kwargs(websocket=websocket)
-
-        fn = cast("AsyncAnyCallable", self.route_handler.fn)
-        if isinstance(self.route_handler.owner, Controller):
-            await fn(self.route_handler.owner, **kwargs)
-        else:
-            await fn(**kwargs)
+        await self.route_handler.fn.value(**kwargs)
 
     async def _resolve_kwargs(self, websocket: "WebSocket[Any, Any]") -> Dict[str, Any]:
         """Resolve the required kwargs from the request data.
@@ -86,10 +73,8 @@ class WebSocketRoute(BaseRoute):
 
         signature_model = get_signature_model(self.route_handler)
         kwargs = self.handler_parameter_model.to_kwargs(connection=websocket)
-        await resolve_dependencies_concurrently(
-            self.handler_parameter_model,
-            self.handler_parameter_model.expected_dependencies,
-            websocket,
-            kwargs,
-        )
+        for dependency in self.handler_parameter_model.expected_dependencies:
+            kwargs[dependency.key] = await self.handler_parameter_model.resolve_dependency(
+                dependency=dependency, connection=websocket, **kwargs
+            )
         return signature_model.parse_values_from_connection_kwargs(connection=websocket, **kwargs)
