@@ -1,11 +1,9 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Literal, Optional, Type, Union, cast
 
 from starlite.app import DEFAULT_CACHE_CONFIG, Starlite
 from starlite.testing.test_client import TestClient
 
 if TYPE_CHECKING:
-    from typing_extensions import Literal
-
     from starlite import (
         BaseLoggingConfig,
         CacheConfig,
@@ -19,6 +17,7 @@ if TYPE_CHECKING:
         TemplateConfig,
         WebSocket,
     )
+    from starlite.config import AllowedHostsConfig
     from starlite.middleware.session.base import BaseBackendConfig
     from starlite.types import (
         AfterExceptionHookHandler,
@@ -47,8 +46,8 @@ def create_test_client(
     after_response: Optional["AfterResponseHookHandler"] = None,
     after_shutdown: Optional["SingleOrList[LifeSpanHookHandler]"] = None,
     after_startup: Optional["SingleOrList[LifeSpanHookHandler]"] = None,
-    allowed_hosts: Optional[List[str]] = None,
-    backend: "Literal['asyncio', 'trio']" = "asyncio",
+    allowed_hosts: Optional[Union[List[str], "AllowedHostsConfig"]] = None,
+    backend: Literal["asyncio", "trio"] = "asyncio",
     backend_options: Optional[Dict[str, Any]] = None,
     base_url: str = "http://testserver.local",
     before_request: Optional["BeforeRequestHookHandler"] = None,
@@ -78,7 +77,7 @@ def create_test_client(
     template_config: Optional["TemplateConfig"] = None,
     websocket_class: Optional[Type["WebSocket"]] = None,
 ) -> TestClient["Starlite"]:
-    """Creates a Starlite app instance and initializes it.
+    """Create a Starlite app instance and initializes it.
 
     [TestClient][starlite.testing.TestClient] with it.
 
@@ -87,7 +86,6 @@ def create_test_client(
             handled correctly.
 
     Examples:
-
         ```python
         from starlite import get, create_test_client
 
